# comparison_sigurdr_siegfried

Comparison *Nibelungenlied* and *Völsunga saga*

The name of the package is **sigurd**.

## Download and Installation

```bash
$ pip install sigurd
```


```python

```

# Origins of the data
* 

# Aim

# Presentation
